#!/bin/ksh
#
# Metop-B test case
#
# Usage: ./metopb_run.sh [ATOVS|IASI]
#
# AAPP_PREFIX must be defined as an environment variable
#
# 1) For ATOVS, you can choose whether or not to run MAIA when mapping AVHRR to HIRS.
#    The default is not to run MAIA. If you want to run MAIA, export RUN_MAIA=yes. GFS forecast
#    files will be downloaded and used.
#
# 2) For IASI, you need to define PATH_OPS as an environment variable, e.g.
#      export PATH_OPS=[OPS-LRS installation directory]/OPS-LRS-run/OPS/perl
#    If you already have a DIR_IASICONFIG set up, you can use it (no checking is performed). If
#    not, the script will create a local one and will download the necessary files from the NWP SAF
#    server.
##############################################################################################

[ $AAPP_PREFIX ] || { echo "AAPP_PREFIX is not defined"; exit; }
[ -d "$AAPP_PREFIX" ] || { echo "AAPP_PREFIX is not a directory"; exit; }

export DIR_NAVIGATION=$PWD/orbelems       #Over-ride default in ATOVS_ENV
export PAR_NAVIGATION_DEFAULT_LISTESAT='M01'
export PAR_NAVIGATION_DEFAULT_LISTEBUL='tle'    #set up for 2-line elements

. "$AAPP_PREFIX/ATOVS_CONF"               #AAPP environment

export WRK=$PWD/work
level0=$PWD/level0
level1=$PWD/level1
if [ -d $level1 ]; then
  rm -rf ${level1}_previous
  echo "re-naming the existing level 1 directory to ${level1}_previous"
  mv $level1 ${level1}_previous
fi

mkdir -p $WRK $level1

#---------ATOVS---------

if [ "$1" = ATOVS ] || [ "$1" = "" ]; then

  if [ "$RUN_MAIA" = "yes" ]; then
    export DIR_FORECAST=$PWD/forecast
    export MAIA4_USE_GFS="yes"
    mkdir -p $DIR_FORECAST
  else
    echo "Not running MAIA (export RUN_MAIA=yes to change it)"
  fi

  cd $WRK

  instr="AMSU-A MHS HIRS AVHRR"
  grids="HIRS"

  time AAPP_RUN_METOP -d $level0 -o $level1 -i "$instr" -g "$grids"  >metopb_atovs.out 2>&1
  status=$?
  if [ $status != 0 ]; then
    echo "AAPP_RUN_METOP failed"
    exit 1
  else
    echo "AAPP_RUN_NOAA ended: output in $level1"
  fi

  cd ..

fi

#---------IASI---------

if  [ "$1" = IASI ] || [ "$1" = "" ]; then

  if [ ! "$PATH_OPS" ]; then
    echo "To run IASI: export PATH_OPS=[directory of ops_process]"
  else
    if [ ! -f "$PATH_OPS/ops_process" ]; then
      echo "$PATH_OPS/ops_process does not exist"
      exit 1
    else
      if [ ! "$DIR_IASICONFIG" ]; then
        export DIR_IASICONFIG=$PWD/aux
        mkdir -p $DIR_IASICONFIG
        echo "Using a local DIR_IASICONFIG=$DIR_IASICONFIG"
        cd $DIR_IASICONFIG
        [ -x get_aux_files.sh ] || \
          { wget --no-check-certificate https://nwp-saf.eumetsat.int/downloads/aapp_data_files/OPS-LRS/aux_data/get_aux_files.sh; chmod +x get_aux_files.sh; }
        echo "Running get_aux_files.sh for M01"
        ./get_aux_files.sh -d 20200731 -s M01 $PWD
        export DIR_IASICONFIG=$PWD
        cd ..
      fi
      cd $WRK
      rm -f AVHR_xxx_1B*   #remove any existing AVHRR PFS-format files
      instr="IASI AVHRR"
      grids=" "

      avh1bfile=$(ls -t $level1/hrpt*.l1b 2>/dev/null | head -1)   #Use the AVHRR 1b file if it is there
      [ "$avh1bfile" ] && ln -sf $avh1bfile .

      echo "running AAPP_RUN_METOP"
      time AAPP_RUN_METOP -b -d $level0 -o $level1 -i "$instr" -g "$grids"  >metopb_iasi.out 2>&1  
      
      echo "run iasi_1c_to_pc"
      cd $level1
      iasifile=$(ls iasi*.l1c)
      iasi_1c_to_pc $iasifile ${iasifile%.l1c}.lpc

    fi
  fi

fi
